@@ -3,6 +3,7 @@
 from __future__ import annotations
 
 __all__ = [
+    'Command',
     'PdbCommand',
     'Event',
     'OnEndCmdloop',
@@ -18,13 +19,14 @@ __all__ = [
     'QueueOut',
     'RunArg',
     'RunResult',
+    'Statement',
     'set_queues',
     'main',
 ]
 
 import traceback
 
-from .commands import PdbCommand
+from .commands import Command, PdbCommand
 from .events import (
     Event,
     OnEndCmdloop,
@@ -38,7 +40,7 @@ from .events import (
     OnWriteStdout,
 )
 from .runner import run
-from .types import QueueIn, QueueOut, RunArg, RunResult
+from .types import QueueIn, QueueOut, RunArg, RunResult, Statement
 
 _queue_in: QueueIn | None = None
 _queue_out: QueueOut | None = None
